[![codeastro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)



# Spectral Information (SpIn)
 
 A package to quick fit continuum, find spectral emission and absorption lines, and fit Voigt profiles to lines.

<p align = "center">
    <img src="/images/continuum_fit_example.png" alt="An example continuum fit with SpIn"/>
    An example continuum fit for an IGRINS spectral order.
</p>


<p align = "center">
    <img src="/images/voigt_fit_example.png" alt="An example Voigt profile line fit with SpIn"/> <br>
    An example absoprtion line profile fit within the above order.
</p>

<p align = "center">
    <img src = "/images/LAE_Full_Spec.png" alt="An example LAE from HETDEX."> <br>
    An example Lyman Alpha Emitter (LAE) from the HETDEX survey. <br>
    <img src = "/images/Found_Lya.png" alt="Fit Lya with Voigt profile using SpIn!."> <br>
    Fitting the Lyman Alpha line using Spin!
</p>